fix_collinear_spin — PyProcar 6.2.1 documentation

Skip to main content
`Ctrl`+`K`

# fix_collinear_spin

ElectronicBandStructure.fix_collinear_spin()

  Converts data from two spin channels to a single channel, adjusting the spin down values to negatives. This is typically used for plotting the Density of States (DOS).

  Parameters:

    No parameters are required for this function.

  Returns:

    bool – Returns True if the function changed the data, False otherwise.